// 
// このコードは、https://demo.mescius.jp/diodocs/pdf のサンプルの一部として提供されています。
// © MESCIUS inc. All rights reserved.
// 
using System;
using System.Drawing;
using System.IO;
using GrapeCity.Documents.Pdf;
using GrapeCity.Documents.Text;

namespace DsPdfWeb.Demos.Basics
{
    // テキストの配置オプション（左揃え/中央揃え/右揃え/両端揃え）を示します
    // （LRT テキストの水平方向の配置）。
    // 
    public class TextAlign
    {
        public int CreatePDF(Stream stream)
        {
            // ランダムなテキストの段落を生成するヘルパー関数です。
            Func<string> makePara = () => Environment.NewLine + Common.Util.getString_ja(0, 0, 2, 2, 5);
            //
            var doc = new GcPdfDocument();
            var g = doc.NewPage().Graphics;
            // Graphics.CreateTextLayout() を使用すると、TextLayout の解像度は
            // グラフィックスの解像度と同じ値（デフォルトでは 72 dpi）に設定されます。
            var tl = g.CreateTextLayout();
            tl.DefaultFormat.FontName = "Yu gothic";
            tl.DefaultFormat.FontSize = 12;
            // レイアウトサイズを設定します（すべてのページに１インチの余白）。
            tl.MaxWidth = doc.Pages.Last.Size.Width - 72 * 2;
            tl.MaxHeight = doc.Pages.Last.Size.Height - 72 * 2;
            // 'ヘッダー'のテキスト書式を太字にします。
            var tf = new TextFormat(tl.DefaultFormat) { Font = StandardFonts.TimesBold };
            // 挿入位置。
            var ip = new PointF(72, 72);
            // TextAlignment は、レイアウト矩形内でテキストが水平方向に配置される方法を制御します。
            // ５つの段落をを異なる配置で描画します。
            // 左揃え：
            tl.TextAlignment = TextAlignment.Leading;
            tl.Append("TextAlignment.Leading: ", tf);
            tl.Append(makePara());
            tl.PerformLayout(true);
            g.DrawTextLayout(tl, ip);
            // 挿入位置を拡張し、段落間に１行分の高さを追加します。
            ip.Y += tl.ContentHeight + tl.Lines[0].Height;
            // 中央揃え：
            tl.Clear();
            tl.TextAlignment = TextAlignment.Center;
            tl.Append("TextAlignment.Center: ", tf);
            tl.Append(makePara());
            tl.PerformLayout(true);
            g.DrawTextLayout(tl, ip);
            // 挿入位置を拡張し、段落間に１行分の高さを追加します。
            ip.Y += tl.ContentHeight + tl.Lines[0].Height;
            // 右揃え：
            tl.Clear();
            tl.TextAlignment = TextAlignment.Trailing;
            tl.Append("TextAlignment.Trailing: ", tf);
            tl.Append(makePara());
            tl.PerformLayout(true);
            g.DrawTextLayout(tl, ip);
            // 挿入位置を拡張し、段落間に１行分の高さを追加します。
            ip.Y += tl.ContentHeight + tl.Lines[0].Height;
            // 両端揃え：
            tl.Clear();
            tl.TextAlignment = TextAlignment.Justified;
            tl.Append("TextAlignment.Justified: ", tf);
            tl.Append(makePara());
            tl.PerformLayout(true);
            g.DrawTextLayout(tl, ip);
            // 挿入位置を拡張し、段落間に１行分の高さを追加します。
            ip.Y += tl.ContentHeight + tl.Lines[0].Height;
            // 分散：
            tl.Clear();
            tl.TextAlignment = TextAlignment.Distributed;
            tl.Append("TextAlignment.Distributed: ", tf);
            tl.Append(makePara());
            tl.PerformLayout(true);
            g.DrawTextLayout(tl, ip);
            // PDF ドキュメントを保存します。
            doc.Save(stream);
            return doc.Pages.Count;
        }
    }
}
